﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Configuration;

namespace Geosys.Prototypes.MapSuite.WebEdition.Pages.TestWithRadAjaxManager
{
    public partial class TestRadAjaxManager : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                InitializeModuleCarto();
            }
        }

        #region Module Carto Initialisation

        private void InitializeModuleCarto()
        {
            InitializeInchedPerUnit();
            InitializeMapAppearance();
            InitializeBackgroundLayer();
            InitializeMapExtend();
            Map1.MapUnit = GeographyUnit.Meter;

        }

        #region Init Current Scale
        public const int DotsPerInch = 96;
        public Dictionary<string, double> inchesPerUnits;

        public void InitializeInchedPerUnit()
        {
            inchesPerUnits = new Dictionary<string, double>();
            inchesPerUnits.Add("DecimalDegree", 4374754);
            inchesPerUnits.Add("Feet", 12.0);
            inchesPerUnits.Add("Meter", 39.3701);
        }
        #endregion

        private void InitializeMapAppearance()
        {
            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
            Map1.MapTools.OverlaySwitcher.Enabled = true;
            Map1.MapTools.MouseCoordinate.Enabled = true;
            Map1.MapTools.PanZoomBar.Enabled = true;
            Map1.MapTools.ScaleLine.Enabled = true;
            Map1.MapTools.Logo.Enabled = true;
        }

        private void InitializeBackgroundLayer()
        {
            GoogleOverlay gOverlay = new GoogleOverlay();
            gOverlay.Name = "Google Overlay";
            gOverlay.GoogleMapType = GoogleMapType.Hybrid;

            string sOverlayMapURL = ConfigurationManager.AppSettings["sOverlayMapURL"];

            gOverlay.JavaScriptLibraryUri = new Uri(sOverlayMapURL);
            gOverlay.IsBaseOverlay = true;

            Map1.CustomOverlays.Add(gOverlay);
        }

        private void InitializeMapExtend()
        {

        }




        private BaseShape ProjectGeometry(BaseShape shapeIn, string projIn, string projOut)
        {
            Proj4Projection proj4 = new Proj4Projection();

            proj4.InternalProjectionParametersString = projIn;
            proj4.ExternalProjectionParametersString = projOut;
            proj4.Open();

            BaseShape shapeOut = proj4.ConvertToExternalProjection(shapeIn);

            proj4.Close();
            return shapeOut;
        }



        #endregion


        protected void btn_Clicked(object sender, EventArgs eas)
        {
            string wkt = "MULTIPOLYGON(((11.9033431990264 48.0080705084386,11.9431686384738 48.0115157706898,11.9414520247053 47.9915300457057,11.9088363630882 47.9834876274198,11.8848037703182 47.9857855890945,11.9033431990264 48.0080705084386)))";

            InMemoryFeatureLayer imLayer = new InMemoryFeatureLayer();
            BaseShape bs = BaseShape.CreateShapeFromWellKnownData(wkt);
            BaseShape bs2 = ProjectGeometry(bs, Proj4Projection.GetEpsgParametersString(4326), Proj4Projection.GetGoogleMapParametersString());
            imLayer.Open();
            imLayer.FeatureSource.BeginTransaction();
            Feature f = bs2.GetFeature();
            imLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush = new GeoSolidBrush(GeoColor.StandardColors.White);
            imLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen = new GeoPen(GeoColor.StandardColors.Black);
            imLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            imLayer.FeatureSource.AddFeature(f);
            imLayer.FeatureSource.CommitTransaction();
            imLayer.FeatureSource.Close();
            LayerOverlay lo = new LayerOverlay();
            lo.IsBaseOverlay = false;
            lo.Layers.Add(imLayer);
            Map1.CustomOverlays.Add(lo);

            Map1.CurrentExtent = bs2.GetBoundingBox();
        }
    }
}
